==> hoteldruid-mod-de_2.3.0-1.zip: de/crearegole.php <==
<?php

switch ($messaggio) {

case "Inserisci le regole di assegnazione per le prenotazioni dell'anno":       $messaggio = "Eintragen der Zuweisungsregeln f&uuml;r das Jahr"; break;
case "Regola di assegnazione":                                                  $messaggio = "Zuweisungsregel"; break;
case "nel periodo dal":                                                         $messaggio = "im Zeitraum von"; break;
case "al":                                                                      $messaggio = "bis"; break;
case "motivazione":                                                             $messaggio = "Grund"; break;
case "Inserisci la regola":                                                     $messaggio = "Regel eintragen"; break;
case "Inserisci o modifica la regola":                                          $messaggio = "Regel einf&uuml;gen oder &auml;ndern"; break;
case "Cancella tutte le regole di questo tipo":                                 $messaggio = "Alle Regeln dieses Typs l&ouml;schen"; break;
case "Quando si sceglie la tariffa":                                            $messaggio = "Bei Auswahl des Tarifes"; break;
case "se non si inserisce nessun altro metodo di assegnazione":                 $messaggio = "wenn keine andere Methode der Zuweisung eingetragen wurde"; break;
case "Vedi le regole già inserite":                                             $messaggio = "Bestehende Regeln anzeigen"; break;
case "Torna al menù principale":                                                $messaggio = "Zum Hauptmen&uuml;"; break;
case "Non sono stati inseriti tutti i dati necessari":                          $messaggio = "Es fehlen notwendige Daten"; break;
case "Le date sono sbagliate":                                                  $messaggio = "Daten sind falsch"; break;
case "La regola è stata inserita":                                              $messaggio = "Die Regel wurde eingetragen"; break;
case "Sei sicuro di voler cancellare tutte le regole del tipo 1":               $messaggio = "Wollen Sie wirklich alle Regeln des Typs 1 l&ouml;schen."; break;
case "SI":                                                                      $messaggio = "Ja"; break;
case "Le regole sono state cancellate":                                         $messaggio = "Die Regeln wurden gel&ouml;scht"; break;
case "Si deve scegliere la tariffa":                                            $messaggio = "Sie m&uuml;ssen den Preis ausw&auml;hlen"; break;
case " non esiste":                                                             $messaggio = " existiert nicht"; break;
case "La regola di assegnazione":                                               $messaggio = "Die Zuweisungsregel"; break;
case "è stata inserita":                                                        $messaggio = "ist hinzugef&uuml;gt worden"; break;
case "è stata modificata":                                                      $messaggio = "ist ge&auml;ndert worden"; break;
case "Torna indietro":                                                          $messaggio = "Zur&uuml;ck"; break;
case "Motivazione non valida":                                                  $messaggio = "Kein g&uuml;ltiger Grund"; break;
case "La tariffa scelta ha già un utente associato, cancella la regola prima di inserirne una nuova":                                                                                 $messaggio = "Der gew&auml;hlte Preis ist bereits mit einem Benutzer verbunden, l&ouml;schen Sie bitte die Regel bevor Sie eine neue eingeben"; break;
case "Quando l'utente amministratore":                                          $messaggio = "Wenn der Administrator"; break;
case "sceglie la tariffa":                                                      $messaggio = "folgenden Tarif ausw&auml;hlt"; break;
case "fai risultare come se l'utente":                                          $messaggio = "zeige es als ob Benutzer"; break;
case "avesse inserito la prenotazione e l'eventuale cliente":                   $messaggio = "die Reservierung und den m&ouml;glichen Kunden eingegeben hat"; break;
case "Si deve inserire l'utente da associare":                                  $messaggio = "Sie m&uuml;ssen den Benutzer ausw&auml;hlen der damit verbunden werden soll"; break;
case "L'utente ":                                                               $messaggio = "Der Benutzer"; break;
case "assegna automaticamente come numero di persone":                          $messaggio = "Anzahl der Personen automatisch zuweisen"; break;
case "se non si inserisce nessun altro numero":                                 $messaggio = "wenn keine andere Zahl eingef&uuml;gt wurde"; break;
case "La tariffa scelta ha già un numero di persone associato, cancella la regola prima di inserirne una nuova":                                                                                 $messaggio = "Der ausgew&auml;hlte Tarif hat bereits eine zugewiesene Anzahl von Personen, l&ouml;schen Sie die Regel bevor Sie eine neue einf&uuml;gen"; break;
case "Si deve inserire il numero di persone da associare":                      $messaggio = "Sie m&uuml;ssen die Anzahl der zu verkn&uuml;pfenden Personen"; break;
case "Eccezioni alla regola":                                                   $messaggio = "Ausnahmen von Regel "; break;
case "e mancano meno di":                                                       $messaggio = " und weniger als"; break;
case "giorni":                                                                  $messaggio = "Tage fehlen"; break;
case "dall'inizio":                                                             $messaggio = "vom Anfang der"; break;
case "dalla fine":                                                              $messaggio = "vom Ende der"; break;
case "della prenotazione quando essa viene inserita, allora":                   $messaggio = "Reservierung wenn diese eingef&uuml;gt wurde, dann"; break;
case "Inserisci o modifica questa eccezione alla regola":                       $messaggio = "Einf&uuml;gen oder &auml;ndern einer Ausnahme von dieser Regel"; break;
case "Si deve inserire il numero di giorni":                                    $messaggio = "Die Anzahl der Tage muss eingef&uuml;gt werden"; break;
case "opzionale":  				$messaggio = "optional"; break;
case "Chiedi prima di assegnare":		$messaggio = "Ask before assigning"; break;
case "Chiudi":  				$messaggio = "Close"; break;
case "Il periodo chiuso è stato liberato dalle prenotazioni":	$messaggio = "The closed period has been freed of reservations"; break;
case "<span class=\"colred\">Non è stato possibile</span> liberare dalle prenotazioni il periodo chiuso":	$messaggio = "<span class=\"colred\">It was not possible</span> to free from reservations the closed period"; break;
case "per le tariffe":  			$messaggio = "for rates"; break;
case "Esiste già una regola di questo tipo nel periodo selezionato":	$messaggio = "A rule of this kind already exists for the selected period"; break;
case "assegna automaticamente":  		$messaggio = "automatically assign"; break;
case "tra":  					$messaggio = "between"; break;
case "da assegnare troppo alto, supera quello presente nella lista":	$messaggio = "to be assigned too high, exceeds the number in the list"; break;
case "Attenzione":  				$messaggio = "Warning"; break;
case "della regola 2 mancanti nella eccezione alla regola":	$messaggio = "in rule 2 that are missing from the exception to the rule"; break;
case "nella regola 2 di questa tariffa che non possono ospitare":	$messaggio = "in the rule 2 for this rate that can't host"; break;
case "persone":  				$messaggio = "people"; break;
case "nella regola di assegnazione 2 di questa tariffa":	$messaggio = "in the assignment rule 2 for this rate"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-de_3.0.8-1.zip: de/crearegole.php <==
<?php

switch ($messaggio) {

case "Inserisci le regole di assegnazione per le prenotazioni dell'anno":       $messaggio = "Eintragen der Zuweisungsregeln f&uuml;r das Jahr"; break;
case "Regola di assegnazione":                                                  $messaggio = "Zuweisungsregel"; break;
case "nel periodo dal":                                                         $messaggio = "im Zeitraum von"; break;
case "al":                                                                      $messaggio = "bis"; break;
case "motivazione":                                                             $messaggio = "Grund"; break;
case "Inserisci la regola":                                                     $messaggio = "Regel eintragen"; break;
case "Inserisci o modifica la regola":                                          $messaggio = "Regel einf&uuml;gen oder &auml;ndern"; break;
case "Cancella tutte le regole di questo tipo":                                 $messaggio = "Alle Regeln dieses Typs l&ouml;schen"; break;
case "Quando si sceglie la tariffa":                                            $messaggio = "Bei Auswahl des Tarifes"; break;
case "se non si inserisce nessun altro metodo di assegnazione":                 $messaggio = "wenn keine andere Methode der Zuweisung eingetragen wurde"; break;
case "Vedi le regole già inserite":                                             $messaggio = "Bestehende Regeln anzeigen"; break;
case "Torna al menù principale":                                                $messaggio = "Zum Hauptmen&uuml;"; break;
case "Non sono stati inseriti tutti i dati necessari":                          $messaggio = "Es fehlen notwendige Daten"; break;
case "Le date sono sbagliate":                                                  $messaggio = "Daten sind falsch"; break;
case "La regola è stata inserita":                                              $messaggio = "Die Regel wurde eingetragen"; break;
case "Sei sicuro di voler cancellare tutte le regole del tipo 1":               $messaggio = "Wollen Sie wirklich alle Regeln des Typs 1 l&ouml;schen."; break;
case "SI":                                                                      $messaggio = "Ja"; break;
case "Le regole sono state cancellate":                                         $messaggio = "Die Regeln wurden gel&ouml;scht"; break;
case "Si deve scegliere la tariffa":                                            $messaggio = "Sie m&uuml;ssen den Preis ausw&auml;hlen"; break;
case " non esiste":                                                             $messaggio = " existiert nicht"; break;
case "La regola di assegnazione":                                               $messaggio = "Die Zuweisungsregel"; break;
case "è stata inserita":                                                        $messaggio = "ist hinzugef&uuml;gt worden"; break;
case "è stata modificata":                                                      $messaggio = "ist ge&auml;ndert worden"; break;
case "Torna indietro":                                                          $messaggio = "Zur&uuml;ck"; break;
case "Motivazione non valida":                                                  $messaggio = "Kein g&uuml;ltiger Grund"; break;
case "La tariffa scelta ha già un utente associato, cancella la regola prima di inserirne una nuova":                                                                                 $messaggio = "Der gew&auml;hlte Preis ist bereits mit einem Benutzer verbunden, l&ouml;schen Sie bitte die Regel bevor Sie eine neue eingeben"; break;
case "Quando l'utente amministratore":                                          $messaggio = "Wenn der Administrator"; break;
case "sceglie la tariffa":                                                      $messaggio = "folgenden Tarif ausw&auml;hlt"; break;
case "fai risultare come se l'utente":                                          $messaggio = "zeige es als ob Benutzer"; break;
case "avesse inserito la prenotazione e l'eventuale cliente":                   $messaggio = "die Reservierung und den m&ouml;glichen Kunden eingegeben hat"; break;
case "Si deve inserire l'utente da associare":                                  $messaggio = "Sie m&uuml;ssen den Benutzer ausw&auml;hlen der damit verbunden werden soll"; break;
case "L'utente ":                                                               $messaggio = "Der Benutzer"; break;
case "assegna automaticamente come numero di persone":                          $messaggio = "Anzahl der Personen automatisch zuweisen"; break;
case "se non si inserisce nessun altro numero":                                 $messaggio = "wenn keine andere Zahl eingef&uuml;gt wurde"; break;
case "La tariffa scelta ha già un numero di persone associato, cancella la regola prima di inserirne una nuova":                                                                                 $messaggio = "Der ausgew&auml;hlte Tarif hat bereits eine zugewiesene Anzahl von Personen, l&ouml;schen Sie die Regel bevor Sie eine neue einf&uuml;gen"; break;
case "Si deve inserire il numero di persone da associare":                      $messaggio = "Sie m&uuml;ssen die Anzahl der zu verkn&uuml;pfenden Personen"; break;
case "Eccezioni alla regola":                                                   $messaggio = "Ausnahmen von Regel "; break;
case "e mancano meno di":                                                       $messaggio = " und weniger als"; break;
case "giorni":                                                                  $messaggio = "Tage fehlen"; break;
case "dall'inizio":                                                             $messaggio = "vom Anfang der"; break;
case "dalla fine":                                                              $messaggio = "vom Ende der"; break;
case "della prenotazione quando essa viene inserita, allora":                   $messaggio = "Reservierung wenn diese eingef&uuml;gt wurde, dann"; break;
case "Inserisci o modifica questa eccezione alla regola":                       $messaggio = "Einf&uuml;gen oder &auml;ndern einer Ausnahme von dieser Regel"; break;
case "Si deve inserire il numero di giorni":                                    $messaggio = "Die Anzahl der Tage muss eingef&uuml;gt werden"; break;
case "Crea Regole":  				$messaggio = "Create Rules"; break;
case "opzionale":  				$messaggio = "optional"; break;
case "Chiedi prima di assegnare":		$messaggio = "Ask before assigning"; break;
case "Chiudi":  				$messaggio = "Close"; break;
case "Il periodo chiuso è stato liberato dalle prenotazioni":	$messaggio = "The closed period has been freed of reservations"; break;
case "<span class=\"colred\">Non è stato possibile</span> liberare dalle prenotazioni il periodo chiuso":	$messaggio = "<span class=\"colred\">It was not possible</span> to free from reservations the closed period"; break;
case "per le tariffe":  			$messaggio = "for rates"; break;
case "Esiste già una regola di questo tipo nel periodo selezionato":	$messaggio = "A rule of this kind already exists for the selected period"; break;
case "assegna automaticamente":  		$messaggio = "automatically assign"; break;
case "tra":  					$messaggio = "between"; break;
case "da assegnare troppo alto, supera quello presente nella lista":	$messaggio = "to be assigned too high, exceeds the number in the list"; break;
case "Attenzione":  				$messaggio = "Warning"; break;
case "della regola 2 mancanti nella eccezione alla regola":	$messaggio = "in rule 2 that are missing from the exception to the rule"; break;
case "nella regola 2 di questa tariffa che non possono ospitare":	$messaggio = "in the rule 2 for this rate that can't host"; break;
case "persone":  				$messaggio = "people"; break;
case "nella regola di assegnazione 2 di questa tariffa":	$messaggio = "in the assignment rule 2 for this rate"; break;
case "Regole esistenti":  			$messaggio = "Existing rules"; break;
case "Cancella o ridimensiona queste regole":  	$messaggio = "Delete or scale down these rules"; break;
case "Cancella":  				$messaggio = "Delete"; break;
case "Ridimensiona":  				$messaggio = "Scale down"; break;
case "Modifica la regola":  			$messaggio = "Modify rule"; break;
case "chiusure":  				$messaggio = "closures"; break;
case "numero di persone":  			$messaggio = "number of people"; break;
case "utente inserimento":  			$messaggio = "inserting user"; break;
case "non permettere l'inserimento di prenotazioni con meno di":	$messaggio = "do not allow inserting reservations with less than"; break;
case "Il numero di persone minimo":  		$messaggio = "The minimum number of people"; break;
case "è maggiore del numero di persone predefinito":	$messaggio = "is bigger then the default number of people"; break;
case "è stata cancellata":  			$messaggio = "has been deleted"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
